# Copyright (c) 2012-2016 Seafile Ltd.
TEXT = 'Text'
IMAGE = 'Image'
DOCUMENT = 'Document'
SVG = 'SVG'
PDF = 'PDF'
MARKDOWN = 'Markdown'
VIDEO = 'Video'
AUDIO = 'Audio'
SPREADSHEET = 'SpreadSheet'
XMIND = 'XMind'
SEADOC = 'SDoc'
TLDRAW = 'Tldraw'


MARKDOWN_SUPPORT_CONVERT_TYPES = ['sdoc']
DOCX_SUPPORT_CONVERT_TYPES = ['sdoc']
SDOC_SUPPORT_CONVERT_TYPES = ['markdown', 'docx']
